@@ -1,40 +1,25 @@
 /**
- * Copyright 2016 Saikrishna Arcot <saiarcot895@gmail.com>
+ * SPDX-FileCopyrightText: 2016 Saikrishna Arcot <saiarcot895@gmail.com>
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License or (at your option) version 3 or any later version
- * accepted by the membership of KDE e.V. (or its successor approved
- * by the membership of KDE e.V.), which shall act as a proxy
- * defined in Section 14 of version 3 of the license.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <https://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
 
 #include "bluetoothlinkprovider.h"
-#include "core_debug.h"
-#include "connectionmultiplexer.h"
-#include "multiplexchannel.h"
 #include "bluetoothdevicelink.h"
+#include "connectionmultiplexer.h"
+#include "core_debug.h"
+#include "multiplexchannel.h"
 
 #include <QBluetoothServiceInfo>
 
 BluetoothLinkProvider::BluetoothLinkProvider()
+    : mServiceUuid(QBluetoothUuid(QStringLiteral("185f3df4-3268-4e3f-9fca-d4d5059915bd")))
+    , mServiceDiscoveryAgent(new QBluetoothServiceDiscoveryAgent(this))
+    , connectTimer(new QTimer(this))
 {
-    mServiceUuid = QBluetoothUuid(QStringLiteral("185f3df4-3268-4e3f-9fca-d4d5059915bd"));
-
-    connectTimer = new QTimer(this);
     connectTimer->setInterval(30000);
     connectTimer->setSingleShot(false);
 
-    mServiceDiscoveryAgent = new QBluetoothServiceDiscoveryAgent(this);
     mServiceDiscoveryAgent->setUuidFilter(mServiceUuid);
     connect(connectTimer, &QTimer::timeout, this, [this]() {
         mServiceDiscoveryAgent->start();
@@ -74,15 +59,16 @@ void BluetoothLinkProvider::onStop()
     mBluetoothServer->deleteLater();
 }
 
-//I'm in a new network, let's be polite and introduce myself
+// I'm in a new network, let's be polite and introduce myself
 void BluetoothLinkProvider::onNetworkChange()
 {
 }
 
 void BluetoothLinkProvider::connectError()
 {
-    QBluetoothSocket* socket = qobject_cast<QBluetoothSocket*>(sender());
-    if (!socket) return;
+    QBluetoothSocket *socket = qobject_cast<QBluetoothSocket *>(sender());
+    if (!socket)
+        return;
 
     qCWarning(KDECONNECT_CORE) << "Couldn't connect to socket:" << socket->errorString();
 
@@ -94,13 +80,12 @@ void BluetoothLinkProvider::connectError()
     socket->deleteLater();
 }
 
-void BluetoothLinkProvider::addLink(BluetoothDeviceLink* deviceLink, const QString& deviceId)
+void BluetoothLinkProvider::addLink(BluetoothDeviceLink *deviceLink, const QString &deviceId)
 {
-    QMap< QString, DeviceLink* >::iterator oldLinkIterator = mLinks.find(deviceId);
+    QMap<QString, DeviceLink *>::iterator oldLinkIterator = mLinks.find(deviceId);
     if (oldLinkIterator != mLinks.end()) {
-        DeviceLink* oldLink = oldLinkIterator.value();
-        disconnect(oldLink, SIGNAL(destroyed(QObject*)),
-                    this, SLOT(deviceLinkDestroyed(QObject*)));
+        DeviceLink *oldLink = oldLinkIterator.value();
+        disconnect(oldLink, SIGNAL(destroyed(QObject *)), this, SLOT(deviceLinkDestroyed(QObject *)));
         oldLink->deleteLater();
         mLinks.erase(oldLinkIterator);
     }
@@ -108,19 +93,20 @@ void BluetoothLinkProvider::addLink(BluetoothDeviceLink* deviceLink, const QStri
     mLinks[deviceId] = deviceLink;
 }
 
-void BluetoothLinkProvider::serviceDiscovered(const QBluetoothServiceInfo& old_info) {
+void BluetoothLinkProvider::serviceDiscovered(const QBluetoothServiceInfo &old_info)
+{
     auto info = old_info;
     info.setServiceUuid(mServiceUuid);
     if (mSockets.contains(info.device().address())) {
         return;
     }
 
-    QBluetoothSocket* socket = new QBluetoothSocket(QBluetoothServiceInfo::RfcommProtocol);
+    QBluetoothSocket *socket = new QBluetoothSocket(QBluetoothServiceInfo::RfcommProtocol);
 
-    //Delay before sending data
+    // Delay before sending data
     QPointer<QBluetoothSocket> deleteableSocket = socket;
-    connect(socket, &QBluetoothSocket::connected, this, [this,deleteableSocket]() {
-        QTimer::singleShot(500, this, [this,deleteableSocket]() {
+    connect(socket, &QBluetoothSocket::connected, this, [this, deleteableSocket]() {
+        QTimer::singleShot(500, this, [this, deleteableSocket]() {
             clientConnected(deleteableSocket);
         });
     });
@@ -135,10 +121,11 @@ void BluetoothLinkProvider::serviceDiscovered(const QBluetoothServiceInfo& old_i
     }
 }
 
-//I'm the new device and I'm connected to the existing device. Time to get data.
+// I'm the new device and I'm connected to the existing device. Time to get data.
 void BluetoothLinkProvider::clientConnected(QPointer<QBluetoothSocket> socket)
 {
-    if (!socket) return;
+    if (!socket)
+        return;
 
     auto peer = socket->peerAddress();
 
@@ -157,14 +144,20 @@ void BluetoothLinkProvider::clientConnected(QPointer<QBluetoothSocket> socket)
     disconnect(socket, nullptr, this, nullptr);
 
     auto channel = QSharedPointer<MultiplexChannel>{multiplexer->getDefaultChannel().release()};
-    connect(channel.data(), &MultiplexChannel::readyRead, this, [this,peer,channel] () { clientIdentityReceived(peer, channel); });
-    connect(channel.data(), &MultiplexChannel::aboutToClose, this, [this,peer,channel] () { socketDisconnected(peer, channel.data()); });
+    connect(channel.data(), &MultiplexChannel::readyRead, this, [this, peer, channel]() {
+        clientIdentityReceived(peer, channel);
+    });
+    connect(channel.data(), &MultiplexChannel::aboutToClose, this, [this, peer, channel]() {
+        socketDisconnected(peer, channel.data());
+    });
 
-    if (channel->bytesAvailable()) clientIdentityReceived(peer, channel);
-    if (!channel->isOpen()) socketDisconnected(peer, channel.data());
+    if (channel->bytesAvailable())
+        clientIdentityReceived(peer, channel);
+    if (!channel->isOpen())
+        socketDisconnected(peer, channel.data());
 }
 
-//I'm the new device and the existing device sent me data.
+// I'm the new device and the existing device sent me data.
 void BluetoothLinkProvider::clientIdentityReceived(const QBluetoothAddress &peer, QSharedPointer<MultiplexChannel> socket)
 {
     socket->startTransaction();
@@ -191,26 +184,24 @@ void BluetoothLinkProvider::clientIdentityReceived(const QBluetoothAddress &peer
 
     qCDebug(KDECONNECT_CORE()) << "Received identity packet from" << peer;
 
-    //TODO?
-    //disconnect(socket, SIGNAL(error(QBluetoothSocket::SocketError)), this, SLOT(connectError()));
+    // TODO?
+    // disconnect(socket, SIGNAL(error(QBluetoothSocket::SocketError)), this, SLOT(connectError()));
 
-    const QString& deviceId = receivedPacket.get<QString>(QStringLiteral("deviceId"));
-    BluetoothDeviceLink* deviceLink = new BluetoothDeviceLink(deviceId, this, mSockets[peer], socket);
+    const QString &deviceId = receivedPacket.get<QString>(QStringLiteral("deviceId"));
+    BluetoothDeviceLink *deviceLink = new BluetoothDeviceLink(deviceId, this, mSockets[peer], socket);
 
     NetworkPacket np2;
     NetworkPacket::createIdentityPacket(&np2);
     success = deviceLink->sendPacket(np2);
 
     if (success) {
-
         qCDebug(KDECONNECT_CORE) << "Handshaking done (I'm the new device)";
 
-        connect(deviceLink, SIGNAL(destroyed(QObject*)),
-                this, SLOT(deviceLinkDestroyed(QObject*)));
+        connect(deviceLink, SIGNAL(destroyed(QObject *)), this, SLOT(deviceLinkDestroyed(QObject *)));
 
         Q_EMIT onConnectionReceived(receivedPacket, deviceLink);
 
-        //We kill any possible link from this same device
+        // We kill any possible link from this same device
         addLink(deviceLink, deviceId);
 
     } else {
@@ -218,13 +209,13 @@ void BluetoothLinkProvider::clientIdentityReceived(const QBluetoothAddress &peer
         delete deviceLink;
     }
 
-    //We don't delete the socket because now it's owned by the BluetoothDeviceLink
+    // We don't delete the socket because now it's owned by the BluetoothDeviceLink
 }
 
-//I'm the existing device, a new device is kindly introducing itself.
+// I'm the existing device, a new device is kindly introducing itself.
 void BluetoothLinkProvider::serverNewConnection()
 {
-    QBluetoothSocket* socket = mBluetoothServer->nextPendingConnection();
+    QBluetoothSocket *socket = mBluetoothServer->nextPendingConnection();
 
     qCDebug(KDECONNECT_CORE()) << "Received connection from" << socket->peerAddress();
 
@@ -243,8 +234,12 @@ void BluetoothLinkProvider::serverNewConnection()
     disconnect(socket, nullptr, this, nullptr);
 
     auto channel = QSharedPointer<MultiplexChannel>{multiplexer->getDefaultChannel().release()};
-    connect(channel.data(), &MultiplexChannel::readyRead, this, [this,peer,channel] () { serverDataReceived(peer, channel); });
-    connect(channel.data(), &MultiplexChannel::aboutToClose, this, [this,peer,channel] () { socketDisconnected(peer, channel.data()); });
+    connect(channel.data(), &MultiplexChannel::readyRead, this, [this, peer, channel]() {
+        serverDataReceived(peer, channel);
+    });
+    connect(channel.data(), &MultiplexChannel::aboutToClose, this, [this, peer, channel]() {
+        socketDisconnected(peer, channel.data());
+    });
 
     if (!channel->isOpen()) {
         socketDisconnected(peer, channel.data());
@@ -258,7 +253,7 @@ void BluetoothLinkProvider::serverNewConnection()
     qCDebug(KDECONNECT_CORE()) << "Sent identity packet to" << socket->peerAddress();
 }
 
-//I'm the existing device and this is the answer to my identity packet (data received)
+// I'm the existing device and this is the answer to my identity packet (data received)
 void BluetoothLinkProvider::serverDataReceived(const QBluetoothAddress &peer, QSharedPointer<MultiplexChannel> socket)
 {
     QByteArray identityArray;
@@ -286,22 +281,21 @@ void BluetoothLinkProvider::serverDataReceived(const QBluetoothAddress &peer, QS
 
     qCDebug(KDECONNECT_CORE()) << "Received identity packet from" << peer;
 
-    const QString& deviceId = receivedPacket.get<QString>(QStringLiteral("deviceId"));
-    BluetoothDeviceLink* deviceLink = new BluetoothDeviceLink(deviceId, this, mSockets[peer], socket);
+    const QString &deviceId = receivedPacket.get<QString>(QStringLiteral("deviceId"));
+    BluetoothDeviceLink *deviceLink = new BluetoothDeviceLink(deviceId, this, mSockets[peer], socket);
 
-    connect(deviceLink, SIGNAL(destroyed(QObject*)),
-            this, SLOT(deviceLinkDestroyed(QObject*)));
+    connect(deviceLink, SIGNAL(destroyed(QObject *)), this, SLOT(deviceLinkDestroyed(QObject *)));
 
     Q_EMIT onConnectionReceived(receivedPacket, deviceLink);
 
     addLink(deviceLink, deviceId);
 }
 
-void BluetoothLinkProvider::deviceLinkDestroyed(QObject* destroyedDeviceLink)
+void BluetoothLinkProvider::deviceLinkDestroyed(QObject *destroyedDeviceLink)
 {
     const QString id = destroyedDeviceLink->property("deviceId").toString();
     qCDebug(KDECONNECT_CORE()) << "Device disconnected:" << id;
-    QMap< QString, DeviceLink* >::iterator oldLinkIterator = mLinks.find(id);
+    QMap<QString, DeviceLink *>::iterator oldLinkIterator = mLinks.find(id);
     if (oldLinkIterator != mLinks.end() && oldLinkIterator.value() == destroyedDeviceLink) {
         mLinks.erase(oldLinkIterator);
     }
@@ -317,5 +311,4 @@ void BluetoothLinkProvider::socketDisconnected(const QBluetoothAddress &peer, Mu
 
 BluetoothLinkProvider::~BluetoothLinkProvider()
 {
-
 }
