@@ -17,48 +17,58 @@ class LinkProvider;
 class Device;
 class QSslCertificate;
 
-class DeviceLink
-    : public QObject
+class DeviceLink : public QObject
 {
     Q_OBJECT
 
 public:
     enum PairStatus { NotPaired, Paired };
 
-    DeviceLink(const QString& deviceId, LinkProvider* parent);
+    DeviceLink(const QString &deviceId, LinkProvider *parent);
     ~DeviceLink() override = default;
 
     virtual QString name() = 0;
 
-    const QString& deviceId() const { return m_deviceId; }
-    LinkProvider* provider() { return m_linkProvider; }
+    const QString &deviceId() const
+    {
+        return m_deviceId;
+    }
+    LinkProvider *provider()
+    {
+        return m_linkProvider;
+    }
 
-    virtual bool sendPacket(NetworkPacket& np) = 0;
+    virtual bool sendPacket(NetworkPacket &np) = 0;
 
-    //user actions
+    // user actions
     virtual void userRequestsPair() = 0;
     virtual void userRequestsUnpair() = 0;
 
-    PairStatus pairStatus() const { return m_pairStatus; }
+    PairStatus pairStatus() const
+    {
+        return m_pairStatus;
+    }
     virtual void setPairStatus(PairStatus status);
 
-    //The daemon will periodically destroy unpaired links if this returns false
-    virtual bool linkShouldBeKeptAlive() { return false; }
+    // The daemon will periodically destroy unpaired links if this returns false
+    virtual bool linkShouldBeKeptAlive()
+    {
+        return false;
+    }
 
     virtual QSslCertificate certificate() const = 0;
 
 Q_SIGNALS:
-    void pairingRequest(PairingHandler* handler);
-    void pairingRequestExpired(PairingHandler* handler);
+    void pairingRequest(PairingHandler *handler);
+    void pairingRequestExpired(PairingHandler *handler);
     void pairStatusChanged(DeviceLink::PairStatus status);
-    void pairingError(const QString& error);
-    void receivedPacket(const NetworkPacket& np);
+    void pairingError(const QString &error);
+    void receivedPacket(const NetworkPacket &np);
 
 private:
     const QString m_deviceId;
-    LinkProvider* m_linkProvider;
+    LinkProvider *m_linkProvider;
     PairStatus m_pairStatus;
-
 };
 
 #endif
